import logging
import os

from launchpadlib.launchpad import Launchpad

lp = None


def _get_lp():
    global lp
    if lp is None:
        lp = Launchpad.login_anonymously(
            'ddeb-retriever',
            os.environ.get('LAUNCHPAD_INSTANCE', 'production'),
            version='devel')


def get_series(distribution):
    '''Get info about current series of given distribution

    Return name -> (components, architectures)
    '''
    _get_lp()
    info = {}
    for s in lp.distributions[distribution].series:
        # FIXME: wily is still marked as supported in LP, but EOL
        if s.name == 'wily':
            continue
        # devel series is active but not supported
        if s.supported or s.active:
            arches = [a['architecture_tag'] for a in
                      lp.load(s.architectures_collection_link).entries]

            info[s.name] = (s.component_names, arches)
    return info


def get_buildds():
    '''Return list of available buildds'''

    _get_lp()
    buildds = []

    for builder in lp.builders:
        if builder.virtualized:
            continue  # ignore PPA buildds
        if not builder.builderok:
            logging.info('builder is disabled: %s', builder.name)
            continue
        buildds.append(builder.name)

    return buildds


def get_binary_publications(distribution, created_since_date=None):
    '''Get recently-published binaries for the given distribution'''

    _get_lp()
    archive = lp.distributions[distribution].main_archive
    # It's important to omit the status filter here, even if we later decide
    # that we only care about the Published status (although at the moment
    # it seems reasonable to scan everything and let the garbage-collection
    # pass clean up superseded ddebs later).  This is because the collection
    # may change as we're iterating over it.  Without any filtering, this is
    # OK because entries can never be removed from the collection: the worst
    # case is that we encounter the same publication twice.  With filtering
    # on mutable properties, it would be possible to lose entries between
    # two successive batches.
    return archive.getPublishedBinaries(
        order_by_date=True, created_since_date=created_since_date)


def make_suite(distroseries, pocket):
    if pocket == 'Release':
        return distroseries.name
    else:
        return '%s-%s' % (distroseries.name, pocket.lower())
